@@ -4,12 +4,11 @@ use crate::utils;
 use failure::{Context, ResultExt};
 
 pub fn run(port: i32) -> Result<(), Context<String>> {
-    let toml = utils::toml_to_struct("Tarantella.toml");
-    let module_type = toml.unwrap().package.module_type;
+    let module_type = utils::check_for_toml_field("module_type")?;
     if module_type.eq("main_module") {
         utils::check_for_command(
             "basic-http-server",
-            "`tapm` depends on basic-http-server. To install it, run: `cargo install basic-http-server`",
+            "tapm depends on basic-http-server. To install it, run: `cargo install basic-http-server`",
         )?;
         let err_msg = "tapm run failed".to_string();
         let mut child = if cfg!(target_os = "windows") {
@@ -28,7 +27,7 @@ pub fn run(port: i32) -> Result<(), Context<String>> {
 
     } else {
         return Err(Context::from(
-            "`tapm run` is a command meant solely for main modules.".to_string(),
+            "tapm run is a command meant solely for main modules.".to_string(),
         ));
     }
 
